@@ -159,7 +159,6 @@ N_("Asia/Barnaul");
 N_("Asia/Beirut");
 N_("Asia/Bishkek");
 N_("Asia/Chita");
-N_("Asia/Choibalsan");
 N_("Asia/Colombo");
 N_("Asia/Damascus");
 N_("Asia/Dhaka");
@@ -239,11 +238,6 @@ N_("Australia/Lord_Howe");
 N_("Australia/Melbourne");
 N_("Australia/Perth");
 N_("Australia/Sydney");
-N_("CET");
-N_("CST6CDT");
-N_("EET");
-N_("EST");
-N_("EST5EDT");
 N_("Etc/GMT");
 N_("Etc/GMT+1");
 N_("Etc/GMT+10");
@@ -310,14 +304,9 @@ N_("Europe/Vilnius");
 N_("Europe/Volgograd");
 N_("Europe/Warsaw");
 N_("Europe/Zurich");
-N_("HST");
 N_("Indian/Chagos");
 N_("Indian/Maldives");
 N_("Indian/Mauritius");
-N_("MET");
-N_("MST");
-N_("MST7MDT");
-N_("PST8PDT");
 N_("Pacific/Apia");
 N_("Pacific/Auckland");
 N_("Pacific/Bougainville");
@@ -348,4 +337,3 @@ N_("Pacific/Rarotonga");
 N_("Pacific/Tahiti");
 N_("Pacific/Tarawa");
 N_("Pacific/Tongatapu");
-N_("WET");
